componenttools.partition_components_by_durations_not_less_than
==============================================================

.. autofunction:: abjad.tools.componenttools.partition_components_by_durations_not_less_than.partition_components_by_durations_not_less_than
   :noindex:
